==============
urban.schedule
==============

Schedule configuration for Urban

Features
--------

- Can be bullet points


Examples
--------

This add-on can be seen in action at the following sites:
- Is there a page on the internet where everybody can see the features?


Documentation
-------------

Full documentation for end users can be found in the "docs" folder, and is also available online at ...


Translations
------------

This product has been translated into

- French


Installation
------------

Install urban.schedule by adding it to your buildout::

    [buildout]

    ...

    eggs =
        urban.schedule


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/IMIO/urban.schedule/issues
- Source Code: https://github.com/IMIO/urban.schedule


Support
-------

If you are having issues, please let us know.


License
-------
The project is licensed under the GPLv2.
